<?php

use yii;

use app\models\connection\Dellin;

use DateTime;

?>

<link href="/css/pages/cart.css" rel="stylesheet">

<div id="page_cart" class="container mb-auto py-3">
    <article class="py-3 px-4 rounded">
        <h4 class="ml-4 mt-2 mb-4"><i class="fas fa-shopping-cart mr-2"></i>Корзина</h4>
        <div class="col mb-4 list rounded overflow-hidden">
            <div class="row py-2">
                <div class="pl-3 mr-1">
                    <input id="checkbox_cart_all" type="checkbox" onchange="return cart_list_checkbox(this);" />
                </div>
                <div class="col-2">
                    <span>Артикул</span>
                </div>
                <div class="col-4">
                    <span>Описание</span>
                </div>
                <div class="col-1 ml-auto  px-0 text-center">
                    <span>Количество</span>
                </div>
                <div class="col-2 text-right">
                    <span>Доставка</span>
                </div>
                <div class="col-2 mr-3 text-right">
                    <span>Стоимость</span>
                </div>
            </div>
            <?php
            if (isset($connections) && !empty($connections)) {
                foreach ($connections as $connection) {
                    // Перебор поставок

                    // Инициализация переменных
                    extract($connection);

                    // Инициализация цены
                    $price_raw = $cost;
                    $price = $price_raw . ' ' . $currency;

                    // Инициализация типа доставки
                    $delivery_type = reset($order_edge_supply)['dlvr']['type'] ?? 'auto';

                    // Инициализация индикатора
                    $delivery_icon = match ($delivery_type) {
                        'avia' => '<i class="mr-1 fas fa-plane"></i>',
                        default => '<i class="mr-1 fas fa-truck"></i>'
                    };

                    // Инициализация доставки
                    if (isset($delivery['error']) || $delivery === '?') {
                        // Не удалось рассчитать доставку

                        // Инициализация времени
                        $delivery = '?';
                    } else {
                        // Удалось рассчитать доставку

                        // Инициализация даты отправки
                        try {
                            // Взять данные из "arrivalToOspSender" (Дата прибытия на терминал-отправитель)

                            $delivery_send_date = DateTime::createFromFormat('Y-m-d', $delivery['orderDates']['arrivalToOspSender'])->getTimestamp();
                        } catch (Throwable $e) {
                            // Взять данные из "pickup" (Дата передачи груза на адресе отправителя)

                            $delivery_send_date = DateTime::createFromFormat('Y-m-d', $delivery['orderDates']['pickup'])->getTimestamp();
                        }

                        // Инициализация времени доставки
                        try {
                            // Доставка по воздуху (подразумевается), данные из "giveoutFromOspReceiver" (Дата и время, с которого груз готов к выдаче на терминале)

                            $delivery_converted = DateTime::createFromFormat('Y-m-d H:i:s', $delivery['orderDates']['giveoutFromOspReceiver'])->getTimestamp();
                        } catch (Throwable $e) {
                            // Автоматическая доставка (подразумевается), данные из "arrivalToOspReceiver" (Дата прибытия натерминал-получатель)

                            $delivery_converted = DateTime::createFromFormat('Y-m-d', $delivery['orderDates']['arrivalToOspReceiver'])->getTimestamp();
                        }
                        $delivery = ceil(($delivery_converted - ($delivery_send_date ?? 0)) / 60 / 60 / 24) + 1;
                    }

                    // Инициализация комментария
                    $comment = $order_edge_supply[0]['comm'] ?? 'Комментарий к заказу';

                    echo <<<HTML
                        <div class="row py-2 cart_list_target">
                            <div class="col">
                                <div class="row">
                                    <div class="pl-3 my-auto mr-1">
                                        <input id="cart_list_checkbox_{$supply['catn']}" type="checkbox" onchange="return cart_list_checkbox(this);"/>
                                    </div>
                                    <div class="col-2 my-auto">
                                        {$supply['catn']}
                                    </div>
                                    <div class="col-4 my-auto">
                                        {$supply['dscr']}
                                    </div>
                                    <div class="col-1 my-auto ml-auto">
                                        <input id="cart_list_amnt_{$supply['catn']}" class="form-control text-center" type="text" value="{$connection['amount']}" onchange="return cart_list_amount_update('{$supply['catn']}', this)" aria-invalid="false">
                                    </div>
                                    <div class="col-2 my-auto text-right">
                                        <p title="Ориентировочно">$delivery_icon <b>~</b>$delivery дн</p>
                                    </div>
                                    <div class="col-2 my-auto mr-3 text-right">
                                    $price
                                    </div>
                                </div>
                                <div class="dropdown-divider"></div>
                                <div class="row mb-1">
                                    <div class="col-12">
                                        <p id="cart_list_comment_{$supply['catn']}" class="mt-0 ml-0 text-break pointer-event" role="button" onclick="return cart_list_comment_edit('{$supply['catn']}', this);">$comment</p>
                                    </div>
                                </div>
                            </div>
                        </div>
                    HTML;
                }
            } else {
                echo <<<HTML
                    <div class="row py-2">
                        <div class="mx-auto py-2">
                            Корзина пуста
                        </div>
                    </div>
                HTML;
            }
            ?>
        </div>
        <div class="row mb-2 mx-0">
            <select id="cart_list_action" class="form-control mr-3 button_clean w-auto" name="CartListAction">
                <option value="none" hidden>Действие с выбранными</option>
                <option value="delete" onclick="return cart_list_delete();">Удалить</option>
            </select>
            <a class="mr-3 btn button_red button_clean" title="Очистить корзину" href="/cart" role="button" onclick="return cart_delete();">
                Очистить
            </a>
            <p class="ml-auto mr-3 cart_field_cost">
                <span id="cart_cost">0</span>
                руб
            </p>
            <a class="btn button_clean button_blue" title="Оформить заказ" href="/orders" role="button" onclick="return cart_request();">
                Оформить заказ
            </a>
        </div>
    </article>
</div>

<script src="/js/textarea.js" defer></script>
<script src="/js/cart.js" defer></script>
<script defer>
    if (document.readyState === "complete") {
        cart_cost_calculate();
    } else {
        document.addEventListener('DOMContentLoaded', function() {
            cart_cost_calculate();
        }, false);
    }
</script>
