<?php

declare(strict_types=1);

use yii;
use yii\bootstrap\ActiveForm;

use app\models\AccountEdgeOrder;
use app\models\Order;
use app\models\OrderEdgeSupply;

// Инициализация
if (
    !yii::$app->user->isGuest
    && yii::$app->user->identity->type === 'administrator'
    || yii::$app->user->identity->type === 'moderator'
) {
    $panel ?? $panel = 'orders_panel_moderation';
} else {
    $panel ?? $panel = 'orders_panel_orders';
}

?>

<link href="/css/pages/orders.css" rel="stylesheet">

<div id="page_orders" class="container mb-auto py-3">
    <?php if ($account_type = (!yii::$app->user->isGuest
        && yii::$app->user->identity->type === 'administrator'
        || yii::$app->user->identity->type === 'moderator')) : ?>
        <div class="orders_panel_menu mb-2">
            <label class="btn button_white mb-0 mr-2" for="orders_panel_moderation">Модерация</label>
            <label class="btn button_white mb-0" for="orders_panel_orders">Мои заказы</label>
        </div>
        <input type="radio" id="orders_panel_moderation" name="main_panel" <?= $panel === 'orders_panel_moderation' ? 'checked' : null ?> />
        <article>
            <div class="orders_panel_moderation_menu mb-3">
                <label class="btn btn-sm button_white mb-0 mr-2" for="orders_panel_moderation_all">Все</label>
                <label class="btn btn-sm button_white mb-0 mr-2" for="orders_panel_moderation_requested">Запрошены</label>
                <label class="btn btn-sm button_white mb-0 mr-2" for="orders_panel_moderation_handled">Обрабатываются</label>
                <label class="btn btn-sm button_white mb-0" for="orders_panel_moderation_completed">Завершены</label>
            </div>
            <?php if (!empty($moderator_orders)) : ?>

                <?php foreach ($moderator_orders as $order) : ?>
                    <div id="<?= $order['order']['_key'] ?>_panel" class="page_order_panel mb-3 py-3 px-4 rounded">
                        <h5 class="row mt-1 mb-3">
                            <?php
                            // Инициализация времени отправки заказа
                            $date = null;

                            foreach ($order['order']['jrnl'] as $entry) {
                                // Перебор записей в журнал

                                if ($entry['action'] === 'requested') {
                                    if (empty($date) || $date <= $entry['date']) {
                                        // Буфер не инициализирован или в него записано более старое событие

                                        // Запись
                                        $date = $entry['date'];
                                    }
                                }
                            }

                            $date = [
                                'H:i' => date('H:i', $date),
                                'm.d.Y' =>  date('m.d.Y', $date)
                            ];

                            ?>
                            <p class="col-auto ml-1 font-weight-bold">#<?= $order['order']['_key'] ?></p>
                            <p class="col-auto mr-1 font-weight-bold">
                                <span class="mr-2"><?= $date['H:i'] ?? 'Неизвестно' ?></span>
                                <span><?= $date['m.d.Y'] ?? 'Неизвестно' ?></span>
                            </p>
                        </h5>
                        <div class="dropdown-divider mb-3"></div>
                        <div class="row px-2">
                            <div id="orders_panel_supplies_<?= $order['order']['_key'] ?>" class="col-3 unselectable">
                                <?php if (!empty($order['supplies'])) : ?>
                                    <?php
                                    // Инициализация счетчика поставок для отрисовки горизонтального разделителя
                                    $count = 1;
                                    ?>

                                    <?php foreach ($order['supplies'] as $supply) : ?>
                                        <?php

                                        // Инициализация обложки
                                        $covr = null;

                                        foreach ($imgs ?? [] as $img) {
                                            // Перебор изображений для обложки

                                            if ($img['covr'] ?? false) {
                                                // Обложка найдена

                                                $covr = $img['h150'];

                                                break;
                                            }
                                        }

                                        if (is_null($covr)) {
                                            // Обложка не инициализирована

                                            if (!$covr = $imgs[0]['h150'] ?? false) {
                                                // Не удалось использовать первое изображение как обложку

                                                // Запись обложки по умолчанию
                                                $covr = '/img/covers/h150/product.png';
                                            }
                                        }

                                        // Инициализация окружения
                                        extract($supply);
                                        ?>

                                        <a id="<?= $supply['catn'] ?>_supply" class="row mb-2 p-2 px-0 rounded row_supply" type="button" onclick="return orders_supply_edit('<?= $supply['catn'] ?>', <?= $order['order']['_key'] ?>);">
                                            <img class="col-auto px-0 h-100 img-fluid rounded" src="<?= $covr ?>" />
                                            <p id="<?= $supply['catn'] ?>_supply_stts_indicator" class="col d-flex text-dark"><?= $product['catn'] . ' x' . $amount ?>
                                                <?php if (Order::checkSuppliesStts($order_edge_supply)) : ?>
                                                    <span id="<?= $supply['catn'] ?>_supply_stts_indicator_icon" class="ml-auto my-auto fas fa-check"></span>
                                                <?php endif ?>
                                            </p>
                                        </a>

                                        <?php if ($count++ < count($order['supplies'])) : ?>
                                            <div class="dropdown-divider mb-2"></div>
                                        <?php endif ?>
                                    <?php endforeach ?>
                                <?php else : ?>
                                    <div class="row">
                                        <p>Поставки не найдены</p>
                                    </div>
                                <?php endif ?>
                            </div>
                            <div id="orders_panel_edit_<?= $order['order']['_key'] ?>" class="px-4 col-6 d-flex flex-column">
                                <p class="my-auto">Выберите поставку</p>
                            </div>
                            <div id="orders_panel_info_<?= $order['order']['_key'] ?>" class="col-3 d-flex flex-column">

                                <?php
                                // Конвертация статуса заказа
                                $status = match ($order['account_edge_order'][0]['type']) {
                                    'requested' => 'Запрошен',
                                    'handled' => 'Обрабатывается',
                                    'completed' => 'Завершен',
                                }
                                ?>

                                <p class="row mt-0 mb-3 px-2"><b>Статус:</b> <span class="ml-auto"><?= $status ?></span></p>
                                <a id="<?= $order['order']['_key'] ?>_button" class="row mt-auto mb-0 text-center text-white btn button_blue button_clean disabled" type="button" onclick="return order_accept('<?= $order['order']['_key'] ?>');">Подтвердить</a>
                            </div>
                        </div>
                        <script>
                            document.addEventListener('DOMContentLoaded', function() {

                                order_init('<?= $order['order']['_key'] ?>');

                            }, false);
                        </script>
                    </div>
                <?php endforeach ?>
            <?php else : ?>
                <div class="page_order_panel py-3 px-4 rounded">
                    <p class="text-center">Заказов нет</p>
                </div>
            <?php endif ?>
        </article>

        <input type="radio" id="orders_panel_orders" name="main_panel" <?= $panel === 'orders_panel_orders' ? 'checked' : null ?> />
    <?php endif ?>

    <article class="page_order_panel mt-3 py-3 px-4 rounded <?= $account_type ?? false ? '' : 'd-block'; ?>">
        <div class="row mt-2 mb-2">
            <h4 class="col ml-4"><i class="fas fa-list mr-2"></i>Заказы</h4>
            <div class="col-auto orders_panel_menu ml-auto text-right">
                <a class="btn btn-sm button_white button_clean font-weight-bold mb-0 mr-2" type="button" onclick="return orders_read('all');">Все</a>
                <a class="btn btn-sm button_white button_clean font-weight-bold mb-0 mr-2" type="button" onclick="return orders_read('requested');">Запрошенные</a>
                <a class="btn btn-sm button_white button_clean font-weight-bold mb-0 mr-2" type="button" onclick="return orders_read('accepted');">Активные</a>
                <a class="btn btn-sm button_white button_clean font-weight-bold mb-0" type="button" onclick="return orders_read('completed');">Завершенные</a>
            </div>
        </div>
        <div class="row mb-4">
            <small class="ml-auto d-flex">
                <a class="btn btn-sm button_white button_clean mb-0 mr-2 l" type="button" onclick="return orders_read('last','<?= time() - 86400 ?>', '<?= time() ?>');">День</a>
                <a class="btn btn-sm button_white button_clean mb-0 mr-2" type="button" onclick="return orders_read('last', '<?= time() - 604800 ?>', '<?= time() ?>');">Неделя</a>
                <a class="btn btn-sm button_white button_clean mb-0 mr-2" type="button" onclick="return orders_read('last', '<?= time() - 2592000 ?>', '<?= time() ?>');">Месяц</a>
                <a class="btn btn-sm button_white button_clean mb-0 mr-2" type="button" onclick="return orders_read('last',' '<?= time() - 31536000 ?>', '<?= time() ?>');">Год</a>
            </small>
            <div class="ml-2 mr-3 d-flex">
                <div class="col-5 my-auto ml-auto px-1 py-0 form-control form-control-sm form_control_clean overflow-hidden">
                    <input id="orders_period_calendar_from" class="ml-auto" type="date" value="<?= $from ?? date('Y-m-d', time() - 604800) ?>" onchange="return orders_read('last', moment(this.value, 'YYYY-MM-DD').unix(), moment(document.getElementById('orders_period_calendar_to').value, 'YYYY-MM-DD').unix());" pattern="[0-9]{4}-[0-9]{2}-[0-9]{2}" />
                    <i class="far fa-calendar-alt my-auto mr-auto"></i>
                </div>
                <p class="col-1 p-0 text-center">-</p>
                <div class="col-5 mr-auto my-auto px-1 py-0 form-control form-control-sm form_control_clean overflow-hidden">
                    <input id="orders_period_calendar_to" class="ml-auto" type="date" value="<?= $to ?? date('Y-m-d', time()) ?>" onchange="return orders_read('last', moment(document.getElementById('orders_period_calendar_from').value, 'YYYY-MM-DD').unix(), moment(this.value, 'YYYY-MM-DD').unix());" pattern="[0-9]{4}-[0-9]{2}-[0-9]{2}" />
                    <i class="far fa-calendar-alt my-auto mr-auto"></i>
                </div>
            </div>
        </div>
        <div class="col mb-4 list rounded">
            <div class="row py-3 text-center">
                <!-- <div class="pl-3 mr-1">
                    <input id="checkbox_cart_all" type="checkbox" onchange="return cart_list_checkbox(this);" />
                </div> -->
                <span class="col-2"><b>Артикул</b></span>
                <span class="col-3"><b>Статус</b></span>
                <span class="col-3"><b>Поступление</b></span>
                <span class="col-2"><b>Количество</b></span>
                <span class="col-2"><b>Стоимость</b></span>
            </div>
            <?php

            if (isset($orders) && !empty($orders)) {
                foreach ($orders as $order) {
                    // Перебор заказов

                    // Инициализация
                    extract($order);

                    if (isset($order['stts']) && $order['stts'] === 'reserved') {
                        // Заказ был резервирован (отменён)

                        continue;
                    }

                    // Пропуск активного заказа (несформированного, корзины)
                    if ($account_edge_order[0]['type'] === 'current') continue;

                    // Деинициализация мусора
                    unset($date);

                    // Инициализация времени подтверждения заказа
                    if (isset($order['jrnl'])) foreach ($order['jrnl'] as $entry) {
                        if ($entry['action'] === 'accepted') $date = date('H:i d.m.Y', $entry['date']);
                    }
                    $date ?? $date = 'Ожидается';

                    // Инициализация буфера поставок
                    $supplies_html = '';

                    // Инициализация общей стоимости поставок
                    $sum = 0;

                    if (isset($supplies)) {
                        // Найдены поставки

                        // Инициализация поставок
                        foreach ($supplies as $supply) {
                            // Перебор поставок

                            // Инициализация окружения
                            extract($supply);

                            // Инициализация связи поставки с заказом (подразумевается, что все одинаковые по основным параметрам)
                            $part = $order_edge_supply[0];

                            // Инициализация доставки
                            if (isset($delivery['error'])) {
                                // Не удалось рассчитать доставку

                                // Инициализация индикатора
                                $date_icon = '';

                                // Инициализация доставки
                                if (isset($part['date'])) {
                                    // Найдены данные в инстанции поставки

                                    // Запись в буфер вывода
                                    // $time = $part['time'] . ' дн';
                                    $date = date('d.m.Y', $part['date']);
                                    $date_html = "<span class=\"m-auto\">$date</span>";
                                } else {
                                    $date = 'Неизвестно';
                                    $date_html = "<small class=\"m-auto\">$date</small>";
                                }

                                // Инициализация стоимости
                                if (isset($part['cost'])) $cost_html = '<span class="m-auto">' . ($cost = $part['cost']) . ' <small>' . $currency . '</small></span>';
                                else $cost_html = '<small class="m-auto">' . ($cost = 'Неизвестно') . '</small>';
                            } else {
                                // Удалось рассчитать доставку

                                // Инициализация типа доставки
                                $time_type = $part['dlvr']['type'] ?? 'auto';

                                // Инициализация индикатора
                                $date_icon = match ($time_type) {
                                    'avia' => '<i class="ml-1 fas fa-plane"></i>',
                                    default => '<i class="ml-1 fas fa-truck"></i>'
                                };

                                // Инициализация доставки
                                if (isset($part['date'])) {
                                    // Найдены данные в инстанции поставки

                                    // Запись в буфер вывода
                                    // $time = $part['time'] . ' дн';
                                    $date = date('d.m.Y', $part['date']);
                                    $date_html = "<span class=\"m-auto\">$date</span>";
                                } else {
                                    // Рассчет времени из данных поставки

                                    try {
                                        $time_converted = DateTime::createFromFormat('Y-m-d H:i:s', $delivery['orderDates']['giveoutFromOspReceiver'])->getTimestamp();
                                    } catch (Exception $e) {
                                        $time_converted = DateTime::createFromFormat('Y-m-d', $delivery['orderDates']['arrivalToOspReceiver'])->getTimestamp();
                                    }
                                    // $time = (ceil(($time_converted - time()) / 60 / 60 / 24) + 1) . ' дн';
                                    $date = date('d.m.Y', $time_converted);
                                    $date_html = "<span class=\"m-auto\">$date</span>";
                                }

                                // Инициализация стоимости
                                if (isset($part['cost'])) $cost_html = '<span class="m-auto">' . ($cost = $part['cost']) . ' <small>' . $currency . '</small></span>';
                                else $cost_html = '<span class="m-auto">' . ($cost = $cost) . ' <small>' . $currency . '</small></span>';
                            }

                            // Инициализация статуса связи поставки
                            $status = OrderEdgeSupply::convertStatusToRussian($part['stts'] ?? '');

                            // Инициализация класса для поставки (если необходимо)
                            $css = match ($part['stts'] ?? '') {
                                'accepted' => ' supply_accepted',
                                default => ''
                            };

                            // Пробела между supply и $css не должно быть
                            $supplies_html .= <<<HTML
                                    <div class="row py-2 supply$css text-center">
                                        <div class="col-2">{$supply['catn']}</div>
                                        <div class="col-3 d-flex"><small class="m-auto">$status</small></div>
                                        <div class="col-3 d-flex">$date_html</div>
                                        <div class="col-2">$amount</div>
                                        <div class="col-2 d-flex">$cost_html</div>
                                    </div>
                                HTML;

                            // Обновление общего счётчика цены
                            $sum += (int) $cost;
                        }
                    }

                    // Инициализация статуса заказа
                    $status = AccountEdgeOrder::convertStatusToRussian($account_edge_order[0]['type']);

                    // Инициализация счета для скачивания
                    $invoice = <<<HTML
                        <a class="text-dark" href="/invoices/{$order['_key']}/download"><i class="fas fa-file-invoice-dollar"></i></a>
                    HTML;

                    echo <<<HTML
                        $supplies_html
                        <div class="row py-2 cart_list_target_total text-center">
                            <div class="col-2">$invoice</div>
                            <div class="col-3"><b>$status</b></div>
                            <div class="col-3"><b>$date</b></div>
                            <div class="col-2"></div>
                            <div class="col-2"><b>$sum <small><b>руб</b></small></b></div>
                        </div>
                    HTML;
                }
            } else {
                echo <<<HTML
                    <div class="row py-2 cart_list_target">
                        <div class="mx-auto py-2">
                            Заказов нет
                        </div>
                    </div>
                HTML;
            }
            ?>
        </div>
    </article>
</div>

<script src="/js/orders.js" defer></script>
<?php if (
    !yii::$app->user->isGuest
    && (yii::$app->user->identity->type === 'administrator'
        || yii::$app->user->identity->type === 'moderator')
) : ?>
    <script src="/js/orders_panel.js" defer></script>
<?php endif ?>
